local ballBuffer <const> = 5

--- Assumes that background image is of size
--- XXX
--- XOX
--- Where each character is the size of the screen, and 'O' is the default view.
function getDrawOffset(screenW, screenH, ballX, ballY)
	local offsetX, offsetY
	if ballY > screenH then
		return 0, 0
	end
	if ballY < ballBuffer then
		offsetY = math.max(ballBuffer, -1 * (ballY - ballBuffer))
	else
		offsetY = 0
	end
	if ballX > 0 and ballX < (screenW - ballBuffer) then
		offsetX = 0
	elseif ballX < ballBuffer then
		offsetX = math.max(-1 * screenW, -1 * (ballX - ballBuffer))
	elseif ballX > (screenW - ballBuffer) then
		offsetX = math.min(screenW * 2, -1 * (ballX - ballBuffer))
	end
	return offsetX, offsetY
end

-- selene: allow(unscoped_variables)
blipper = {}

--- Build an object that simply "blips" between the given images at the given interval.
--- Expects `playdate.graphics.animation.blinker.updateAll()` to be called on every update.
function blipper.new(msInterval, imagePath1, imagePath2)
	local blinker = playdate.graphics.animation.blinker.new(msInterval, msInterval, true)
	blinker:start()
	return {
		blinker = blinker,
		image1 = playdate.graphics.image.new(imagePath1),
		image2 = playdate.graphics.image.new(imagePath2),
		draw = function(self, disableBlipping, x, y)
			local currentImage = (disableBlipping or self.blinker.on) and self.image2 or self.image1
			currentImage:draw(x, y)
		end,
	}
end
